package com.xkrs.dao;

import com.xkrs.model.entity.FileEntity;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.data.jpa.repository.Query;
import org.springframework.stereotype.Component;

import java.util.Optional;

/**
 * @Author: XinYi Song
 * @Date: 2022/1/20 15:23
 */
@Component
public interface FileDao extends JpaRepository<FileEntity, Long>, JpaSpecificationExecutor<FileEntity> {

    /**
     * 查询文件信息
     *
     * @param lotNo         批次号
     * @param machineNo     机器号
     * @param materialNo    物料号
     * @param modelNo       模具号
     * @param machineTypeNo 机种号
     * @param craftItemName 工艺项目名称
     * @return
     */
    @Query(value = "SELECT * FROM qc_inspection_file WHERE lot_no = ? AND machine_no = ? AND material_no = ? AND model_no = ? AND machine_type_no = ? AND craft_item_name = ? ", nativeQuery = true)
    Optional<FileEntity> selectFile(String lotNo, String machineNo, String materialNo, String modelNo, String machineTypeNo, String craftItemName);

    /**
     * 修改模板上传信息
     *
     * @param lotNo          批次号
     * @param machineNo      机器号
     * @param materialNo     物料号
     * @param modelNo        模具号
     * @param machineTypeNo  机种号
     * @param craftItemName  工艺项目名称
     * @param fileUploadPath 模板路径
     */
    @Modifying(clearAutomatically = true)
    @Query(value = "UPDATE qc_inspection_file SET file_upload_path = ?7 WHERE lot_no = ?1 AND machine_no = ?2 AND material_no = ?3 AND model_no = ?4 AND machine_type_no = ?5 AND craft_item_name = ?6 ", nativeQuery = true)
    void updateFileUploadPath(String lotNo, String machineNo, String materialNo, String modelNo, String machineTypeNo, String craftItemName, String fileUploadPath);

    /**
     * 修改文件下载信息
     *
     * @param lotNo            批次号
     * @param machineNo        机器号
     * @param materialNo       物料号
     * @param modelNo          模具号
     * @param machineTypeNo    机种号
     * @param craftItemName    工艺项目名称
     * @param fileDownloadPath 文件下载路径
     */
    @Modifying(clearAutomatically = true)
    @Query(value = "UPDATE qc_inspection_file SET file_download_path = ?7 WHERE lot_no = ?1 AND machine_no = ?2 AND material_no = ?3 AND model_no = ?4 AND machine_type_no = ?5 AND craft_item_name = ?6 ", nativeQuery = true)
    void updateFileDownloadPath(String lotNo, String machineNo, String materialNo, String modelNo, String machineTypeNo, String craftItemName, String fileDownloadPath);


}
